﻿using System;
using System.Reflection;
using System.Threading;
using gov.va.med.VBECS.Communication.Channels;
using gov.va.med.VBECS.Communication.Clients;
using gov.va.med.VBECS.Communication.Common;
using gov.va.med.vbecs.Common.Log;

namespace ClientDemo.Demos
{
    public class SequentialMessager : IClientDemo
    {
        ILogger _logger = LogManager.Instance().LoggerLocator.GetLogger(MethodBase.GetCurrentMethod().DeclaringType);

        public void Dispose()
        {
            throw new NotImplementedException();
        }

        public void Start()
        {
            Console.WriteLine("Press enter to connect to the server...");
            Console.ReadLine(); //Wait user to press enter

            using (var client = ClientFactory.CreateEchoClient<MockPinger>())
            {
                client.Connect();
                using (var sequentialMessager = new SequentialMessager<IClient, Pinger>(client) {Timeout = 1000*60})
                {
                    sequentialMessager.MessageReceived += client_message_received;
                    sequentialMessager.Start(); //Start request/reply messenger
                    var key = ConsoleKey.C;

                    while (true)
                    {
                        if (key == ConsoleKey.C)
                            do_start(sequentialMessager);
                        if (key == ConsoleKey.B)
                            do_start_blocking(sequentialMessager);

                        Console.WriteLine("\n\rPress Escape to disconnect from server or C to send again");

                        while (true)
                        {
                            Thread.Sleep(100);
                            key = Console.ReadKey(true).Key;
                            if (key == ConsoleKey.C || key == ConsoleKey.B) break;
                            if (key == ConsoleKey.Escape) break;
                        }

                        if (key == ConsoleKey.Escape) break;
                    }
                }
            }
        }

        protected virtual void do_start_blocking(IMessager client)
        {
            const string messageText = "Blocking Message";
            var aMessage = new TextMessage(messageText);
            IMessage message = null;
            try
            {
                Console.WriteLine("Start sending blocking message [{1}]: {0}", aMessage.Text, aMessage.Id);
                message = ((SequentialMessager<IClient, Pinger>)client).SendReceive(aMessage, 10000);
            }
            catch (Exception e)
            {
                Console.WriteLine("Error message (blocking): " + e.Message);
            }
            Console.WriteLine("Response to blocking message [{1}]: {0}", new TextMessage(message.GetBytes()).Text, message.RepliedId);
            
        }

        protected virtual void do_start(IMessager client)
        {
            for(var i = 0; i < 10; i++)
            {
                var messageText = i + "00";
                var aMessage = new TextMessage(messageText);
                ((SequentialMessager<IClient, Pinger>)client).Send(aMessage, 10000,
                                                            delegate(IMessage message)
                                                                {
                                                                    try
                                                                    {
                                                                        Console.WriteLine(
                                                                            "Response to message [{1}]: {0}",
                                                                            new TextMessage(message.GetBytes()).Text,
                                                                            message.RepliedId);
                                                                    }
                                                                    catch (Exception e)
                                                                    {
                                                                        Console.WriteLine("Error message: " + e.Message);
                                                                    }
                                                                });
                Console.WriteLine("A message sent [{1}]: {0}", aMessage.Text, aMessage.Id);
            }
        }

        static void client_message_received(object sender, MessageEventArgs e)
        {
            var message = e.Message as TextMessage; //Server only accepts text messages
            if (message == null && e.Message is RawDataMessage)
            {
                // Try to construct message from RawMessage
                message = new TextMessage(((RawDataMessage)e.Message).Data);
            }
            if (message == null) return;

            Console.WriteLine("Response from messager [{0}]: " + message.Text, e.Message.RepliedId);
        }

    }
}
