﻿using System;
using System.Configuration;
using System.Diagnostics;
using System.Net;
using System.Reflection;
using System.Threading;
using gov.va.med.VBECS.Communication.Channels;
using gov.va.med.VBECS.Communication.Clients;
using gov.va.med.VBECS.Communication.Common;
using gov.va.med.VBECS.Communication.Utils;
using gov.va.med.vbecs.Common.Log;

namespace ClientDemo.Demos
{
    public class SimpleLoop : IClientDemo
    {
        ILogger _logger = LogManager.Instance().LoggerLocator.GetLogger(MethodBase.GetCurrentMethod().DeclaringType);
        static int _counter = 1;

        public void Dispose()
        {
            throw new NotImplementedException();
        }

        public void Start()
        {
            Console.WriteLine("Press enter to connect to the server...");
            Console.ReadLine(); //Wait user to press enter

            //Read server IP address/ Port
            var serverIp = ConfigurationManager.AppSettings.Get("ServerIP");
            var serverPort = ConfigurationManager.AppSettings.Get("ServerPort");
            using (var client = ClientFactory.CreateClient<MockPinger>(new IPEndPoint(IPAddress.Parse(serverIp), int.Parse(serverPort))))
            {
                client.Connect();

                while (true)
                {
                    ConsoleKey key;
                    while(_counter < 2)
                        do_start(client);

                    Console.WriteLine("\n\rPress Escape to disconnect from server or C to send again");

                    while (true)
                    {
                        Thread.Sleep(100);
                        key = Console.ReadKey(true).Key;
                        if (key == ConsoleKey.C) break;
                        if (key == ConsoleKey.Escape) break;
                    }

                    if (key == ConsoleKey.Escape) break;
                }
            }
        }

        protected virtual void do_start(IMessager client)
        {
            string filename = null;
            try
            {
                filename = ConfigurationManager.AppSettings.Get("InputMessage");
            }
// ReSharper disable EmptyGeneralCatchClause
            catch { }
// ReSharper restore EmptyGeneralCatchClause

            IMessage message;
            if (filename == null)
            {
                Console.Write("Write some message to be sent to server: ");
                message = new TextMessage(Console.ReadLine()); //Get a message from user
            }
            else
            {
                Console.Write("Deserialize message from the file: " + filename + _counter + ".txt");
                IMessageSerializer sr = new TextMessageSerializer();
                message = sr.DeSerializeObject(filename + _counter++ + ".txt");
            }

            client.MessageReceived -= client_message_received;
            client.MessageReceived += client_message_received;
            client.Send(message);
            Console.Write("Message sent!");
        }

        void client_message_received(object sender, MessageEventArgs e)
        {
            var message = e.Message as TextMessage; //Server only accepts text messages
            if (message == null && e.Message is RawDataMessage)
            {
                // Try to construct message from RawMessage
                message = new TextMessage(((RawDataMessage)e.Message).Data);
            }
            if (message == null) return;

            Console.WriteLine("Response from messager: " + message.Text);
        }

    }
}
