#if NUNIT
#region Directives
//-----------------------***
using System;
using System.Collections;
using System.Data;
using System.Text;
using NUnit.Framework;
using gov.va.med.vbecs.UnitTest.VAL;
using gov.va.med.vbecs.UnitTests;

using TABLES = gov.va.med.vbecs.Common.VbecsTables;
using SPROCS = gov.va.med.vbecs.Common.VbecsStoredProcs;
using ARTIFICIAL = gov.va.med.vbecs.Common.DatabaseConstants.ArtificialColumnNames;


using BOL = gov.va.med.vbecs.BOL;
using COMMON = gov.va.med.vbecs.Common;
using DAL = gov.va.med.vbecs.DAL;
using VAL = gov.va.med.vbecs.VAL;
using gov.va.med.vbecs.VAL.UnitTests;
//-----------------------***
using RPC = gov.va.med.vbecs.DAL.VAL.RPC;

#endregion
namespace gov.va.med.vbecs.VAL.UnitTests
{
	[TestFixture]
	public class VAL_OrderEntry  : BaseTest
	{
		public const string PATIENT_SELECT_STATEMENT = "SELECT * FROM  Patient WHERE VistaPatientId = 9875333 AND PatientSsn = 666666666";
		public const string PATIENT_INSERT_STATEMENT = "INSERT INTO Patient (PatientGuid, VistaPatientId, PatientSsn, PatientIcn, PatientLastName, PatientFirstName, PatientMiddleName, PatientDob, PatientDobCode, PatientSexCode, LastUpdateUser, LastUpdateFunctionId, LastUpdateDate)" +
			"VALUES (NewID(), 9875333, 666666666, '1111111111111111', 'TEST', 'UNIT', 'A', '01/01/1950', 'B', 'M', 'zzzzzztomlib', 0, GetUtcDate())";
		public const string PATIENT_DELETE_STATEMENT = "DELETE FROM Patient WHERE VistaPatientId = 0 AND PatientSsn = 666666666";
		public const string UNIT_SELECT_STATEMENT = "SELECT DonationType.RestrictionTypeCode, " +
			"BloodUnit.EyeReadableUnitId, ProductType.ProductTypeName, " +
			"BloodProduct.ProductCode, BloodUnitMedia.BloodTypeCode, " +
			"BloodUnitMedia.RhFactorCode, BloodUnit.OriginlVolume, " +
			"dbo.fnDateTimeConversionToFileManDateTime(OrderedUnit.SelectedDate) FROM	UnitStatus" +
			"INNER JOIN 	BloodUnitStatusCodeCurrent" +
			"	on 	UnitStatus.UnitStatusCode = BloodUnitStatusCodeCurrent.UnitStatusCode" +
			"INNER JOIN 	BloodUnit" +
			"	on 	BloodUnitStatusCodeCurrent.BloodUnitGUID = BloodUnit.BloodUnitGUID" +
			"INNER JOIN 	OrderedUnit" +
			"	on 	BloodUnit.BloodUnitGUID = OrderedUnit.BloodUnitGUID" +
			"INNER JOIN 	OrderedComponent" +
			"	on 	OrderedUnit.OrderedComponentGUID = OrderedComponent.OrderedComponentGUID" +
			"INNER JOIN 	PatientOrder" +
			"	on 	OrderedComponent.PatientOrderGUID = PatientOrder.PatientOrderGUID" +
			"INNER JOIN 	PatientTreatment" +
			"	on 	PatientOrder.PatientTreatmentGUID = PatientTreatment.PatientTreatmentGUID" +
			"INNER JOIN 	Patient" +
			"	on 	PatientTreatment.PatientGUID = Patient.PatientGUID" +
			"INNER JOIN 	BloodProduct" +
			"	on 	BloodUnit.BloodProductGUID = BloodProduct.BloodProductGUID" +
			"INNER JOIN 	ProductType" +
			"	on 	BloodProduct.ProductTypeCode = ProductType.ProductTypeCode" +
			"INNER JOIN 	VamcDivision" +
			"	on 	BloodUnit.DivisionCode = VamcDivision.DivisionCode" +
			"INNER JOIN 	BloodUnitMedia" +
			"	on 	BloodUnit.BloodUnitGUID = BloodUnitMedia.BloodUnitGUID" +
			"WHERE		Patient.VistaPatientID = 0" +
			"	AND	UnitStatus.UnitStatusCode IN ( 'S', 'C' )" +
			"	AND	BloodUnitMedia.UnitExpirationDate > GETUTCDATE()";

		public DataTable dtPatient;
		public RPC.OrderEntry _testOrderEntryRpc;

		[SetUp]
		protected void SetUp()
		{
			this.BaseSetUp();

			VistALinkUnitTestHarness.RequireConnection();

			if (this.RefreshData)
			{
				dtPatient = GetPatientData();
				this.RefreshData = false;
			}

			_testOrderEntryRpc = new RPC.OrderEntry();
		}

		[TearDown]
		protected void TearDown()
		{
			VistALinkUnitTestHarness.ReleaseConnection(); 
		}

		[Test]
		public void GetBloodBankOrderData_Pass()
		{
			GetBloodBankDataUnitTest("Patient","D:/GetBloodBankOrderData_Pass.xml",null);
		}

		[Test]
		[ExpectedException(typeof(ArgumentNullException))]
		public void GetBloodBankOrderData_Fail()
		{
			_testOrderEntryRpc.GetBloodBankOrderData(null, "589");
		}

		[Test]
		[ExpectedException(typeof(ArgumentNullException))]
		public void GetBloodBankOrderData_Fail_2()
		{
			_testOrderEntryRpc.GetBloodBankOrderData(dtPatient.Rows[0][Common.VbecsTables.Patient.VistaPatientId].ToString(), null);
		}

		[Test]
		public void GetBloodBankOrderData_Pass_2()
		{
			GetBloodBankDataUnitTest("TransfusionReaction","D:/GetBloodBankOrderData_Pass_2.xml",null);
		}

		[Test]
		public void GetBloodBankData_Pass_3()
		{
			GetBloodBankDataUnitTest("Antibody","D:/GetBloodBankOrderData_Pass_3.xml",null);
		}

		[Test]
		public void GetBloodBankData_Pass_4()
		{
			GetBloodBankDataUnitTest("Unit","D:/GetBloodBankOrderData_Pass_4.xml","A");
		}

		[Test]
		public void GetBloodBankData_Pass_5()
		{
			GetBloodBankDataUnitTest("Unit","D:/GetBloodBankOrderData_Pass_5.xml","D");
		}

		[Test]
		public void GetBloodBankData_Pass_6()
		{
			GetBloodBankDataUnitTest("Unit","D:/GetBloodBankOrderData_Pass_6.xml","C");
		}

		[Test]
		public void GetBloodBankData_Pass_7()
		{
			GetBloodBankDataUnitTest("Unit","D:/GetBloodBankOrderData_Pass_7.xml","S");
		}

		[Test]
		public void GetBloodBankData_Pass_8()
		{
			GetBloodBankDataUnitTest("Specimen","D:/GetBloodBankOrderData_Pass_8.xml",null);
		}

		[Test]
		public void GetBloodBankData_Pass_9()
		{
			GetBloodBankDataUnitTest("Component","D:/GetBloodBankOrderData_Pass_9.xml",null);
		}

		[Test]
		public void GetBloodBankData_Pass_10()
		{
			GetBloodBankDataUnitTest("LabTest","D:/GetBloodBankOrderData_Pass_10.xml",null);
		}

		[Test]
		public void GetBloodBankData_Pass_11()
		{
			GetBloodBankDataUnitTest("Msbos","D:/GetBloodBankOrderData_Pass_11.xml",null);
		}

		[Test]
		public void GetBloodBankData_Pass_12()
		{
			GetBloodBankDataUnitTest("Surgery","D:/GetBloodBankOrderData_Pass_12.xml",null);
		}

		/// <summary>
		/// Utility used to unit test RPC Functions and validate XML elements and attributes by saving
		/// a copy of the xml to the local drive for visual validation.
		/// </summary>
		/// <param name="nameOfDataElement">Name of the XML Element to validate</param>
		/// <param name="fileName">File path to store XML file.</param>
		/// <param name="unitStatusCode">Unit status code used to search for specific units. Acceptible values are
		/// A=Autologous, D=Directed, C=Crossmatched, S=Assigned.</param>
		private void GetBloodBankDataUnitTest(string nameOfDataElement, string fileName, string unitStatusCode)
		{
			bool valueFound = false;

			if(dtPatient.Rows.Count > 0)
			{
				foreach( DataRow drPatient in dtPatient.Rows )
				{
					string xmlString = _testOrderEntryRpc.GetBloodBankOrderData(drPatient[Common.VbecsTables.Patient.VistaPatientId].ToString(), "589");
					Assert.IsNotNull(xmlString);

					DataSet ds = RpcFunctionUnitTestUtility_VAL.LoadXmlStringIntoDataSet(xmlString);

					for(int i=0; (i < ds.Tables.Count ) && (!valueFound); i++)
					{
						if( ds.Tables[i].TableName == nameOfDataElement )
						{
							switch(nameOfDataElement)
							{
								case "Patient":
									if((ds.Tables[i].Columns.Contains("abo")) && 
										(ds.Tables[i].Columns.Contains("rh")) && 
										(ds.Tables[i].Columns.Contains("dfn")) && 
										(ds.Tables[i].Columns.Contains("firstName")) && 
										(ds.Tables[i].Columns.Contains("lastName")) && 
										(ds.Tables[i].Columns.Contains("ssn")))
										valueFound = true;
									break;

								case "TransfusionReaction":
									if( (ds.Tables[i].Columns.Contains("type")) && 
										(ds.Tables[i].Columns.Contains("date")) )
										valueFound = true;
									break;
								
								case "Antibody":
									if( (ds.Tables[i].Columns.Contains("name")) )
										valueFound = true;
									break;

								case "Unit":
									if( (ds.Tables[i].Columns.Contains("status")) && 
										(ds.Tables[i].Columns.Contains("id")) && 
										(ds.Tables[i].Columns.Contains("product")) && 
										(ds.Tables[i].Columns.Contains("location")) && 
										(ds.Tables[i].Columns.Contains("expDate")) && 
										(ds.Tables[i].Rows[0]["status"].ToString() == unitStatusCode))
										valueFound = true;
									break;

								case "Specimen":
									if( (ds.Tables[i].Columns.Contains("expDate")) && 
										(ds.Tables[i].Columns.Contains("uid")) )
										valueFound = true;
									break;

								case "Component":
									if( (ds.Tables[i].Columns.Contains("name")) && 
										(ds.Tables[i].Columns.Contains("id")) )
										valueFound = true;
									break;

								case "LabTest":
									if( (ds.Tables[i].Columns.Contains("id")) && 
										(ds.Tables[i].Columns.Contains("name")) )
										valueFound = true;
									break;

								case "Msbos":
									if( (ds.Tables[i].Columns.Contains("name")) && 
										(ds.Tables[i].Columns.Contains("threshold")) )
										valueFound = true;
									break;

								case "Surgery":
									if( (ds.Tables[i].Columns.Contains("name")) )
										valueFound = true;
									break;

								default:
									break;
							}
						}
					}
					if(valueFound)
						break;
				}
			}

			
			Assert.IsTrue(true);
//			if(!valueFound)
//				Assertion.Fail("No " + nameOfDataElement + " data found in database for unit test.");
		}

		private DataTable GetPatientData()
		{
			DataTable dt = UnitTestUtil.RunSQLGetDataTable(PATIENT_SELECT_STATEMENT);
			if (dt.Rows.Count < 1) 
			{
				if (CreateUnitTestPatient() == 1)
				{
					DataTable dt2 = UnitTestUtil.RunSQLGetDataTable(PATIENT_SELECT_STATEMENT);
					if( dt2.Rows.Count > 0 )
					{
						return dt2;
					}
					else
						Assert.Fail("Unable to create new patient entry in database");
				}

			}
			return dt;
		}

		private int CreateUnitTestPatient()
		{
			return UnitTestUtil.RunSQL(PATIENT_INSERT_STATEMENT);
		}


		private int CreateUnitTestUnitData()
		{
			return UnitTestUtil.RunSQL("insert");
		}

		[Test]
		public void Ctor_Pass()
		{
			Assert.IsNotNull( _testOrderEntryRpc );
		}

		[Test]
		[Ignore( StandardIgnoreReasons.NoFailureConditions )]
		public void Ctor_Fail() {}
	}
}
#endif
